#!/bin/sh
#
#------------------------------------------------------------------------
#
#   IBM Software
#   Licensed Material - Property of IBM
#   (C) Copyright International Business Machines Corp. 2014
#   All Rights Reserved.
#
#   U.S. Government Users Restricted Rights - Use, duplication or
#   disclosure restricted by GSA ADP Schedule Contract with
#   IBM Corp.
#
#------------------------------------------------------------------------
#   disk_image-set_root_password.sh
#------------------------------------------------------------------------

TMP_MOUNT_POINT=/tmp/mambodiskimage

CURR_USER=`whoami`

usage() {
  echo "  Please specify the disk image filename"
  echo "  eg: $0 fedora-ppc64.img"
}

# Check for one command line argument
if [ $# -ne 1 ]
then
  echo "Error: Incorrect number of arguments"
  usage
  exit 1
fi

if [ "$CURR_USER" != "root" ]
then
  echo "Error: this script must be run with superuser privileges"
  echo "  Please re-run as root or with sudo"
  exit 2
fi

DISKIMG="$1"
if [ -f "$DISKIMG" ]
then
  echo "Resetting root password on disk image $DISKIMG"
else
  echo "ERROR: $DISKIMG does not exist"
  usage
  exit 3
fi

echo "Creating temporary mount point for disk image $TMP_MOUNT_POINT"
mkdir $TMP_MOUNT_POINT
echo "Mounting disk image on $TMP_MOUNT_POINT"
mount -o loop ${DISKIMG} $TMP_MOUNT_POINT

# Fedora disk image has file mode bits set to 000 - temporarily change them
#if [ "$DISKIMG_FILE" == "$BE_DISKIMG_FILE" ]
#then
#  echo "Changing permissions on ${TMP_MOUNT_POINT}/etc/shadow to allow password reset"
#  chmod 600 ${TMP_MOUNT_POINT}/etc/shadow
#fi

echo "Resetting root password to \"mambo\""
sed -i 's/^root.*/root:\$1\$FtoDr9V\/$odjhYhb\.8VdqZ4f3Y5Ly4\.:15863:0:99999:7:::/' \
${TMP_MOUNT_POINT}/etc/shadow

# change them back
#if [ "$DISKIMG_FILE" == "$BE_DISKIMG_FILE" ]
#then
#  echo "Restoring permissions on ${TMP_MOUNT_POINT}/etc/shadow"
#  chmod 000 ${TMP_MOUNT_POINT}/etc/shadow
#fi

echo "Unmounting disk image"
umount $TMP_MOUNT_POINT
echo "Removing temporary mount point $TMP_MOUNT_POINT"
rmdir $TMP_MOUNT_POINT

echo "Success: disk image $DISKIMG should now have root password of \"mambo\""
