#!/bin/bash
#
#------------------------------------------------------------------------
#
#   IBM Software
#   Licensed Material - Property of IBM
#   (C) Copyright International Business Machines Corp. 2014
#   All Rights Reserved.
#
#   U.S. Government Users Restricted Rights - Use, duplication or
#   disclosure restricted by GSA ADP Schedule Contract with
#   IBM Corp.
#
#------------------------------------------------------------------------
#   fetch_disk_image.sh
#------------------------------------------------------------------------

DISKIMG_LOC=ftp://ftp.unicamp.br/pub/linuxpatch/systemsim-p8
BE_DISKIMG_FILE=fedora-ppc64.img.bz2
LE_DISKIMG_FILE=debian-ppc64le-rootfs-v2.0.img.bz2

usage() {
  echo "  Please specify either -be or -le"
  echo "  eg: $0 -be   : fetches big endian disk image"
  echo "      $0 -le   : fetches little endian disk image"
}

check_deps() {
  for DEP in wget bzip2
  do
    DEP_PATH=`which $DEP 2>/dev/null`
    if [ "$DEP_PATH" == "" ]
    then
      echo "Error: $DEP command not found"
      echo "  Please install $DEP and try again"
      exit 2
    fi
  done
}

# Check for one command line argument
if [ $# -ne 1 ]
then
  echo "Error: Incorrect number of arguments"
  usage
  exit 1
fi

check_deps

DISKIMG_FILE=""
if [ "$1" == "-be" ]
then
  echo "Fetching big endian disk image"
  DISKIMG_FILE=$BE_DISKIMG_FILE
elif [ "$1" == "-le" ]
then
  echo "Fetching little endian disk image"
  DISKIMG_FILE=$LE_DISKIMG_FILE
else
  echo "ERROR: Unknown endianness specified"
  usage
  exit 3
fi

wget ${DISKIMG_LOC}/${DISKIMG_FILE}

echo "Uncompressing disk image..."
bunzip2 ${DISKIMG_FILE}
DISKIMG=`echo $DISKIMG_FILE | rev | cut -c 5- | rev`

echo "Disk image downloaded: $DISKIMG"
