#!/bin/sh
#
#------------------------------------------------------------------------
#
#   IBM Software
#   Licensed Material - Property of IBM
#   (C) Copyright International Business Machines Corp. 2014
#   All Rights Reserved.
#
#   U.S. Government Users Restricted Rights - Use, duplication or
#   disclosure restricted by GSA ADP Schedule Contract with
#   IBM Corp.
#
#------------------------------------------------------------------------
#   disk_image-set_root_password.sh
#------------------------------------------------------------------------

PATCH_LOC=ftp://ftp.unicamp.br/pub/linuxpatch/systemsim-p8

TMP_MOUNT_POINT=/tmp/mambodiskimage

CURR_USER=`whoami`

DISKIMG_LE=debian-ppc64le-rootfs-v2.0.img
DISKIMG_BE=fedora-ppc64.img

VMLINUX_ORIG=./vmlinux.orig

usage() {
  echo "  Please specify the disk image filename where the original vmlinux can be found"
  echo "  eg: $0 fedora-ppc64.img"
}

check_deps() {
  for DEP in wget xdelta3
  do
    DEP_PATH=`which $DEP 2>/dev/null`
    if [ "$DEP_PATH" == "" ]
    then
      echo "Error: $DEP command not found"
      echo "  Please install $DEP and try again"
      exit 2
    fi
  done
}

# Check for one command line argument
if [ $# -ne 1 ]
then
  echo "Error: Incorrect number of arguments"
  usage
  exit 1
fi

if [ "$CURR_USER" != "root" ]
then
  echo "Error: this script must be run with superuser privileges"
  echo "  Please re-run as root or with sudo"
  exit 2
fi

DISKIMG="$1"
if [ "$DISKIMG" = "$DISKIMG_LE" ]
then
  VMLINUX_PATCHFILE=systemsim_le_bd.patch
  VMLINUX_PATCHED=./vmlinux-le.patched
  VMLINUX_ORIG=vmlinux-3.16-1-powerpc64le
elif [ "$DISKIMG" = "$DISKIMG_BE" ]
then
  VMLINUX_PATCHFILE=systemsim_bd.patch
  VMLINUX_PATCHED=./vmlinux-be.patched
  VMLINUX_ORIG=vmlinux
else
  echo "Error: unknown disk image..."
  echo "  Binary kernel patches only available for $DISKIMG_BE and $DISKIMG_LE"
  usage
  exit 3
fi

if [ -f "$DISKIMG" ]
then
  echo "Using disk image $DISKIMG"
else
  echo "ERROR: $DISKIMG does not exist"
  usage
  exit 4
fi

echo "Creating temporary mount point for disk image $TMP_MOUNT_POINT"
mkdir $TMP_MOUNT_POINT
echo "Mounting disk image on $TMP_MOUNT_POINT"
mount -o loop ${DISKIMG} $TMP_MOUNT_POINT

echo "Extracting vmlinux from ${TMP_MOUNT_POINT}/boot/${VMLINUX_ORIG}"
cp ${TMP_MOUNT_POINT}/boot/${VMLINUX_ORIG} $VMLINUX_ORIG
echo "Downloading binary patch"
wget ${PATCH_LOC}/${VMLINUX_PATCHFILE}
echo "Patching kernel"
xdelta3 -f -d -s $VMLINUX_ORIG $VMLINUX_PATCHFILE $VMLINUX_PATCHED

if [ $? -ne 0 ]
then
  echo "Error: Patching failed..."
  SUCCESS=0
else
  SUCCESS=1
fi

echo "Unmounting disk image"
umount $TMP_MOUNT_POINT
echo "Removing temporary mount point $TMP_MOUNT_POINT"
rmdir $TMP_MOUNT_POINT
echo "Removing binary patch and original unpatched kernel"
rm $VMLINUX_PATCHFILE
rm $VMLINUX_ORIG

if [ $SUCCESS = 1 ]
then
  echo "Success: patched vmlinux $VMLINUX_PATCHED"
fi
